pub fn render_html(
plan: &LayoutPlan<'_>,
theme: &Theme,
) -> Result<String, RenderError>Expand description
Renders a layout plan and theme into a self-contained HTML string.
pub fn render_html(
plan: &LayoutPlan<'_>,
theme: &Theme,
) -> Result<String, RenderError>Renders a layout plan and theme into a self-contained HTML string.